<?php

namespace Drupal\eca_report\Controller;

/**
 * Controller for ECA actions plugin report.
 *
 * @see \Drupal\Core\Annotation\Action
 * @see \Drupal\eca\PluginManager\Action
 */
class EcaReportActionsController extends EcaReportBaseController {

  /**
   * {@inheritdoc}
   */
  protected string $pluginType = 'action';

  /**
   * {@inheritdoc}
   */
  public function index(): array {
    // Header.
    $header = [
      'label' => ['data' => $this->t('Label / Description'), 'width' => '20%'],
      'id' => ['data' => $this->t('Id'), 'width' => '20%'],
      'type' => ['data' => $this->t('Type'), 'width' => '20%'],
      'config' => ['data' => $this->t('Default configuration'), 'width' => '20%'],
      'used' => ['data' => $this->t('Used in'), 'width' => '20%'],
    ];

    // Items.
    $items = [];
    $used_in = $this->getUsedIn();
    /** @var \Drupal\eca\PluginManager\Action $plugin_manager */
    $plugin_manager = $this->pluginManager;
    $definitions = $plugin_manager
      ->getDecoratedActionManager()
      ->getDefinitions();
    foreach ($definitions as $plugin_id => $definition) {
      /** @var \Drupal\eca\Plugin\Action\ActionBase $plugin */
      $plugin = $this->pluginManager->createInstance($plugin_id);

      $item = [];

      // Label.
      $item['label'] = $this->buildLabelDescription($plugin);

      // ID.
      $item['id'] = $plugin_id;

      // Type.
      $item['type'] = $definition['type'];

      // Configuration.
      $item['configuration'] = $this->buildConfiguration($plugin);

      // Used.
      $item['used'] = [
        'data' => [
          '#theme' => 'item_list',
          '#items' => $used_in[$plugin_id] ?? [],
          '#context' => ['list_style' => 'comma-list'],
        ],
      ];

      $this->appendItem($items, $item, $definition);
    }

    return $this->buildItems($header, $items);
  }

}
