<?php

namespace Drupal\eca_report\Controller;

/**
 * Controller for ECA conditions plugin report.
 *
 * @see \Drupal\eca\Annotation\EcaCondition
 * @see \Drupal\eca\PluginManager\Condition
 */
class EcaReportConditionsController extends EcaReportBaseController {

  /**
   * {@inheritdoc}
   */
  protected string $pluginType = 'condition';

  /**
   * {@inheritdoc}
   */
  public function index(): array {
    // Header.
    $header = [
      'label' => ['data' => $this->t('Label / Description'), 'width' => '20%'],
      'id' => ['data' => $this->t('Id'), 'width' => '20%'],
      'config' => ['data' => $this->t('Default configuration'), 'width' => '20%'],
      'context' => ['data' => $this->t('Context definitions'), 'width' => '20%'],
      'used' => ['data' => $this->t('Used in'), 'width' => '20%'],
    ];

    // Items.
    $items = [];
    $used_in = $this->getUsedIn();
    $definitions = $this->pluginManager->getDefinitions();
    foreach ($definitions as $plugin_id => $definition) {
      /** @var \Drupal\eca\Plugin\ECA\Condition\ConditionBase $plugin */
      $plugin = $this->pluginManager->createInstance($plugin_id);

      $item = [];

      // Label.
      $item['label'] = $this->buildLabelDescription($plugin);

      // ID.
      $item['id'] = $plugin_id;

      // Configuration.
      $item['configuration'] = $this->buildConfiguration($plugin);

      // Context.
      $contexts = [];
      foreach ($plugin->getContextDefinitions() as $context_definition) {
        $context = $context_definition->getLabel();
        if ($context_definition->getDescription()) {
          $context .= ': ' . $context_definition->getDescription();
        }
        $contexts[] = $context;
      }
      $item['context'] = [
        'data' => [
          '#theme' => 'item_list',
          '#items' => $contexts,
        ],
      ];

      // Used.
      $item['used'] = [
        'data' => [
          '#theme' => 'item_list',
          '#items' => $used_in[$plugin_id] ?? [],
          '#context' => ['list_style' => 'comma-list'],
        ]
      ];

      $this->appendItem($items, $item, $definition);
    }

    return $this->buildItems($header, $items);
  }

}
