<?php

namespace Drupal\eca_report\Controller;

/**
 * Controller for ECA events plugin report.
 *
 * @see \Drupal\eca\Annotation\EcaEvent
 * @see \Drupal\eca\PluginManager\Event
 */
class EcaReportEventsController extends EcaReportBaseController {

  /**
   * {@inheritdoc}
   */
  protected string $pluginType = 'event';

  /**
   * {@inheritdoc}
   */
  public function index(): array {
    // Header.
    $header = [
      'label' => ['data' => $this->t('Label'), 'width' => '15%'],
      'name' => ['data' => $this->t('Name'), 'width' => '15%'],
      'config' => ['data' => $this->t('Default configuration'), 'width' => '20%'],
      'tokens' => ['data' => $this->t('Provided tokens'), 'width' => '30%'],
      'used' => ['data' => $this->t('Used in'), 'width' => '20%'],
    ];

    // Items.
    $items = [];
    $used_in = $this->getUsedIn();
    $definitions = $this->pluginManager->getDefinitions();
    foreach ($definitions as $plugin_id => $definition) {
      /** @var \Drupal\eca\Plugin\ECA\Event\EventBase $plugin */
      $plugin = $this->pluginManager->createInstance($plugin_id);

      $item = [];

      // Label.
      $item['label'] = $this->buildLabelDescription($plugin);

      // Name.
      $item['name'] = $plugin->eventName();

      // Configuration.
      $item['configuration'] = $this->buildConfiguration($plugin);

      // Tokens.
      $tokens = [];
      foreach ($plugin->getTokens() as $token) {
        $tokens[$token->name] = '[' . $token->name . ']: ' . $token->description;
      }
      $item['tokens'] = [
        'data' => [
          '#theme' => 'item_list',
          '#items' => $tokens,
        ],
      ];

      // Used.
      $item['used'] = [
        'data' => [
          '#theme' => 'item_list',
          '#items' => $used_in[$plugin_id] ?? [],
          '#context' => ['list_style' => 'comma-list'],
        ]
      ];

      $this->appendItem($items, $item, $definition);
    }

    return $this->buildItems($header, $items);
  }

}
